<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>ClipGrab</name>
    <message>
        <location filename="clipgrab.cpp" line="36"/>
        <source>Automatic language recognition</source>
        <translation>Automatyczne rozpoznawanie języka</translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="512"/>
        <source>Downloading update … %1/%2 MBytes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="521"/>
        <source>There was an error while downloading the update.: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="535"/>
        <source>The fingerprint of the downloaded update file could not be verified: %1 should have been %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="547"/>
        <source>Could not open update file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="585"/>
        <source>Unable to write to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="607"/>
        <source>SSL error: %1 
%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="614"/>
        <source>Error downloading youtube-dl: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="805"/>
        <source>B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="805"/>
        <source>KiB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="805"/>
        <source>MiB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="805"/>
        <source>GiB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="805"/>
        <source>TiB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DownloadListModel</name>
    <message>
        <location filename="download_list_model.cpp" line="99"/>
        <source>Starting ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="download_list_model.cpp" line="106"/>
        <source>Converting ...</source>
        <translation type="unfinished">KOnwertowanie ...</translation>
    </message>
    <message>
        <location filename="download_list_model.cpp" line="108"/>
        <source>Finished</source>
        <translation type="unfinished">Zakończone</translation>
    </message>
    <message>
        <location filename="download_list_model.cpp" line="110"/>
        <source>Paused</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="download_list_model.cpp" line="112"/>
        <source>Canceled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="download_list_model.cpp" line="114"/>
        <source>Waiting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="download_list_model.cpp" line="116"/>
        <source>Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="download_list_model.h" line="37"/>
        <source>Portal</source>
        <translation type="unfinished">Strona</translation>
    </message>
    <message>
        <location filename="download_list_model.h" line="37"/>
        <source>Title</source>
        <translation type="unfinished">Tytuł</translation>
    </message>
    <message>
        <location filename="download_list_model.h" line="37"/>
        <source>Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="download_list_model.h" line="37"/>
        <source>Format</source>
        <translation type="unfinished">Format</translation>
    </message>
    <message>
        <location filename="download_list_model.h" line="37"/>
        <source>Progress</source>
        <translation type="unfinished">Postęp</translation>
    </message>
</context>
<context>
    <name>HelperDownloader</name>
    <message>
        <location filename="helper_downloader.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="helper_downloader.ui" line="20"/>
        <source>Continue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="helper_downloader.ui" line="27"/>
        <source>Exit ClipGrab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="helper_downloader.ui" line="85"/>
        <source>&lt;p&gt;ClipGrab uses youtube-dl in order to download videos from the Internet. youtube-dl is developed by an independent team of Open Source developers and released into the public domain.&lt;br&gt;Learn more on &lt;a href=&quot;https://youtube-dl.org&quot;&gt;youtube-dl.org&lt;/a&gt;.&lt;/p&gt;&lt;p&gt;Click on &lt;em&gt;Continue&lt;/em&gt; to download youtube-dl.&lt;/p&gt;</source>
        <oldsource>&lt;p&gt;ClipGrab uses youtube-dl in order to download videos from the Internet. youtube-dl is developed by an independent team of Open Source developers and released into the public domain.&lt;br&gt;Learn more on &lt;a href=&quot;https://youtube-dl.org&quot;&gt;youtube-dl.org&lt;/a&gt;.&lt;/p&gt;&lt;p&gt;Click on &lt;em&gt;Continue&lt;/em&gt; to automatically download youtube-dl.&lt;/p&gt;</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="helper_downloader.ui" line="99"/>
        <source>Downloading youtube-dl</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.cpp" line="273"/>
        <source>Select Target</source>
        <translation type="unfinished">Wybierz cel</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="74"/>
        <source>Please wait while ClipGrab is loading information about the video ...</source>
        <translation>Zaczekaj, aż ClipGrab załaduje informacje o filmie ...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="327"/>
        <source>Please enter the link to the video you want to download in the field below.</source>
        <translation>Wklej link do filmu, które chcesz pobrać, w pole poniżej.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="333"/>
        <source>No downloadable video could be found.&lt;br /&gt;Maybe you have entered the wrong link or there is a problem with your connection.</source>
        <translation>Brak filmu, który może zostać pobrany.&lt;br /&gt;Może wklejony został nieprawidłowy link lub jest problem z połączeniem internetowym.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="376"/>
        <source>ClipGrab - Select target path</source>
        <translation>ClipGrab - Wybierz ścieżkę docelową</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="415"/>
        <source>ClipGrab: Video discovered in your clipboard</source>
        <translation>ClipGrab: Odkryto link do filmu w schowku systemowym</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="415"/>
        <source>ClipGrab has discovered the address of a compatible video in your clipboard. Click on this message to download it now.</source>
        <translation>ClipGrab odkrył link do filmu z obsługiwanego serwisu w schowku systemowym. Kliknij na tą wiadomość, aby go pobrać.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="499"/>
        <source>ClipGrab - Exit confirmation</source>
        <translation>ClipGrab - Potwierdzenie wyjścia</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="499"/>
        <source>There is still at least one download in progress.&lt;br /&gt;If you exit the program now, all downloads will be canceled and cannot be recovered later.&lt;br /&gt;Do you really want to quit ClipGrab now?</source>
        <translation>Jeden proces pobierania odbywa się w tle.&lt;br /&gt;Jeżeli program zostanie zamknięty, wszystkie procesy pobierania zostaną anulowane, i nie będzie można ich wznowić.&lt;br /&gt;Czy napewno chcesz zamknąc teraz program?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="527"/>
        <source>Download finished</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="527"/>
        <source>Downloading and converting “%title” is now finished.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="529"/>
        <source>All downloads finished</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="529"/>
        <source>ClipGrab has finished downloading and converting all selected videos.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="683"/>
        <source>No results found.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="740"/>
        <source>&amp;Open downloaded file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="741"/>
        <source>Open &amp;target folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="743"/>
        <source>&amp;Pause download</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="744"/>
        <source>&amp;Restart download</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="745"/>
        <source>&amp;Cancel download</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="747"/>
        <source>Copy &amp;video link</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="748"/>
        <source>Open video link in &amp;browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="751"/>
        <source>Resume download</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="764"/>
        <source>Show in &amp;Finder</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindowClass</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>ClipGrab - Download and Convert Online Videos</source>
        <translation>ClipGrab - Pobieraj i konwertuj filmy z internetu</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="153"/>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="172"/>
        <source>Enter keywords in the box below in order to search videos on YouTube</source>
        <translation>Wprowadź słowa kluczowe w polu poniżej w celu wyszukania filmów na YouTube</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="190"/>
        <source>Downloads</source>
        <translation>Pobrania</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="199"/>
        <source>Grab this clip!</source>
        <translation>Pobierz film!</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="234"/>
        <source>Quality:</source>
        <translation>Jakość:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="250"/>
        <source>Please enter the link to the video you want to download in the field below.</source>
        <translation>Wklej link do filmu, który chcesz pobrać, do poniższego pola. </translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="291"/>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="343"/>
        <source>Current Downloads:</source>
        <translation>Aktualne pobrania:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="363"/>
        <source>Cancel selected download</source>
        <translation>Anuluj wybrane pobieranie</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="353"/>
        <source>Open the target folder of the selected download</source>
        <translation>Otwórz folder docelowy wybranego pobierania</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="373"/>
        <source>Pause selected download</source>
        <translation>Zatrzymaj wybrane pobieranie</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="385"/>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="398"/>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="422"/>
        <source>Here you can adjust some general settings concerning the behaviour of ClipGrab.</source>
        <translation>Tutaj możesz dostosować kilka ogólnych ustawień dotyczących zachowania ClipGraba.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="433"/>
        <source>Target Path</source>
        <translation>Ścieżka docelowa</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="439"/>
        <source>Always save at the last used path.</source>
        <translation>Zawsze zachowuj ostatnią lokalizację pobierania.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="453"/>
        <source>Here you can configure where the downloaded videos are to be saved.</source>
        <translation>Tutaj możesz skonfigurować, gdzie pobierane będą pliki.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="460"/>
        <source>Browse ...</source>
        <translation>Przeglądaj ...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="467"/>
        <source>Never ask for file name</source>
        <translation>Nigdy nie pytaj o nazwę pliku</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="488"/>
        <source>Metadata</source>
        <translation>Metadane</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="494"/>
        <source>Here you can configure if ClipGrab is supposed to add metadata (ID3 tags) to your mp3 files.</source>
        <translation>Tutaj możesz skonfigurować, jak ClipGrab ma dodawać metadane (tagi ID3) do plików MP3.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="501"/>
        <source>Use metadata</source>
        <translation>Użyj metadanych</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="522"/>
        <source>Clipboard</source>
        <translation>Schowek</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="528"/>
        <source>Here you can configure how ClipGrab behaves when a downloadable video is discovered in your clipboard.</source>
        <translation>Tutaj możesz skonfigurować, jak ClipGrab będzie się zachowywać, gdy odkryje w schowku link do pobrania.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="535"/>
        <source>Always download</source>
        <translation>Zawsze pobieraj</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="542"/>
        <source>Never download</source>
        <translation>Nigdy nie pobieraj</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="549"/>
        <source>Always ask</source>
        <translation>Zawsze pytaj</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="570"/>
        <source>Notifications</source>
        <translation>Powiadomienia</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="576"/>
        <source>After each download</source>
        <translation>Po każdym pobraniu</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="583"/>
        <source>After all downloads have been completed</source>
        <translation>Po zakończeniu wszystkich pobrań</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="603"/>
        <source>Here you can configure when ClipGrab is supposed to display notifications.</source>
        <translation>Tutaj możesz skonfigurować, kiedy ClipGrab ma wyświetlać powiadomienia.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="610"/>
        <source>Never</source>
        <translation>Nigdy</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="618"/>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="624"/>
        <source>Use a proxy server</source>
        <translation>Użyj serwera proxy</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="634"/>
        <source>Proxy settings</source>
        <translation>Ustawienia proxy</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="643"/>
        <source>Hostname/IP:</source>
        <translation>Nazwa hosta/IP:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="650"/>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="677"/>
        <source>Proxy type:</source>
        <translation>Typ proxy:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="685"/>
        <source>HTTP Proxy</source>
        <translation>HTTP Proxy</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="690"/>
        <source>Socks5 Proxy</source>
        <translation>Socks5 Proxy</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="717"/>
        <source>Proxy authentication</source>
        <translation>Logowanie proxy</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="723"/>
        <source>Username:</source>
        <translation>Login:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="740"/>
        <source>Password:</source>
        <translation>Hasło:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="753"/>
        <source>Proxy requires authentication</source>
        <translation>Proxy wymaga zalogowania</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="761"/>
        <source>Other</source>
        <translation>Inne</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="788"/>
        <source>Remove finished downloads from list</source>
        <translation>Usuń zakończone pobierania z listy</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1182"/>
        <source>&lt;h2&gt;Thanks&lt;/h2&gt;
ClipGrab relies on the work of the Qt project, the ffmpeg team, and the youtube-dl team.&lt;br&gt;
Visit &lt;a href=&quot;https://www.qt.io&quot;&gt;qt.io&lt;/a&gt;, &lt;a href=&quot;https://ffmpeg.org&quot;&gt;ffmpeg.org&lt;/a&gt;, and &lt;a href=&quot;https://youtube-dl.org&quot;&gt;youtube-dl.org&lt;/a&gt; for further information.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="767"/>
        <source>Minimize ClipGrab to the system tray</source>
        <translation>Zminimalizuj ClipGrab do zasobnika systemowego</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="774"/>
        <source>Use WebM if possible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="781"/>
        <source>Ignore SSL errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="808"/>
        <source>Remember logins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="815"/>
        <source>Remember video quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="827"/>
        <source>Language</source>
        <translation>Język</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="851"/>
        <source>Here you can change the language of ClipGrab.</source>
        <translation>Tutaj możesz zmienić język programu.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="858"/>
        <source>Please select a language from the list below. You have to restart ClipGrab in order to apply you selection.</source>
        <translation>Wybierz język z poniższej listy. Musisz uruchomić ponownie ClipGrab, aby wczytać nowe ustawienia.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="895"/>
        <source>Conversion</source>
        <translation>Konwersja</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="918"/>
        <source>Experts can create custom presets for the video conversion here.</source>
        <translation>Eksperci mogą tutaj tworzyć własne schematy dla konwersji wideo.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="925"/>
        <source>Format preset</source>
        <translation>Sformstuj schemat</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="935"/>
        <source>Add new preset</source>
        <translation>Dodaj nowy schemat</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="942"/>
        <source>Remove selected preset</source>
        <translation>Usuń wybrany schemat</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="965"/>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="977"/>
        <location filename="mainwindow.ui" line="1029"/>
        <source>Codec</source>
        <translation>Kodek</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1003"/>
        <location filename="mainwindow.ui" line="1091"/>
        <source>Bitrate (kb/s)</source>
        <translation>Bitrate (kb/s)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1010"/>
        <source>Disable Audio</source>
        <translation>Wyłącz audio</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1020"/>
        <source>Video</source>
        <translation>Wideo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1042"/>
        <source>Frames/second</source>
        <translation>Klatek/sekundę</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1101"/>
        <source>Disable video</source>
        <translation>Wyłącz wideo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1116"/>
        <source>About</source>
        <translation>O programie</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1165"/>
        <source>&lt;h2&gt;Translation&lt;/h2&gt;
ClipGrab is already available in many languages. If ClipGrab has not been translated into your language yet and if you want to contribute a translation, please check &lt;a href=&quot;http://clipgrab.de/translate&quot;&gt;http://clipgrab.de/translate&lt;/a&gt; for further information.</source>
        <translation>&lt;h2&gt;Tłumaczenie&lt;/h2&gt;
Autor polskiego tłumaczenia: Michał Ćwikliński (&lt;a href=&quot;mailto:michal@cwiklinski.it&quot;&gt;michal@cwiklinski.it&lt;/a&gt;).</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1122"/>
        <source>&lt;h2&gt;Support ClipGrab!&lt;/h2&gt;
&lt;p&gt;Only with your support, ClipGrab can remain free software!&lt;br&gt;So if you like ClipGrab and also want to help ensuring its further development, please consider making a donation.&lt;/p&gt;</source>
        <translation>&lt;h2&gt;Wesprzyj ClipGrab!&lt;/h2&gt;
&lt;p&gt;Tylko z twoim wsparciem, ClipGrab pozostanie darmowym programem!&lt;br&gt;Tak więc, jeśli podoba ci się ClipGrab i chcesz pomóc w dalszym jego rozwoju, rozważ małą wpłatę.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>MetadataDialog</name>
    <message>
        <location filename="metadata-dialog.ui" line="14"/>
        <source>ClipGrab - enter metadata</source>
        <translation>ClipGrab - wprowadź metadane</translation>
    </message>
    <message>
        <location filename="metadata-dialog.ui" line="25"/>
        <source>Please enter the metadata for your download. If you don&apos;t want to add metadata, just leave the fields empty.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="metadata-dialog.ui" line="45"/>
        <source>Title:</source>
        <translation>Tytuł:</translation>
    </message>
    <message>
        <location filename="metadata-dialog.ui" line="52"/>
        <source>Artist:</source>
        <translation>Artysta:</translation>
    </message>
</context>
<context>
    <name>UpdateMessage</name>
    <message>
        <location filename="update_message.ui" line="14"/>
        <source>Update for ClipGrab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="update_message.ui" line="116"/>
        <source>ClipGrab %1 is now available (you are using %2). Would you like to install the update?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="update_message.ui" line="130"/>
        <source>There is an update for your version of ClipGrab!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="update_message.ui" line="64"/>
        <source>Skip this update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="update_message.ui" line="91"/>
        <source>Download update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="update_message.ui" line="240"/>
        <source>about:blank</source>
        <translation type="unfinished">about:blank</translation>
    </message>
    <message>
        <location filename="update_message.ui" line="74"/>
        <source>Remind me later</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="update_message.ui" line="41"/>
        <source>The update will begin in just a moment …</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>converter_copy</name>
    <message>
        <location filename="converter_copy.cpp" line="28"/>
        <source>Original</source>
        <translation>Oryginalna</translation>
    </message>
</context>
<context>
    <name>converter_ffmpeg</name>
    <message>
        <location filename="converter_ffmpeg.cpp" line="216"/>
        <source>MPEG4</source>
        <translation>MPEG4</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="217"/>
        <source>WMV (Windows)</source>
        <translation>WMV (Windows)</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="218"/>
        <source>OGG Theora</source>
        <translation>OGG Theora</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="219"/>
        <source>MP3 (audio only)</source>
        <translation>MP3 (tylko audio)</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="220"/>
        <source>OGG Vorbis (audio only)</source>
        <translation>OGG Vorbis (tylko audio)</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="221"/>
        <source>Original (audio only)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="356"/>
        <source>No installed version of avconv or ffmpeg coud be found. Converting files and downloading 1080p videos from YouTube is not supported.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="371"/>
        <source>The installed version of %1 is outdated.
Downloading 1080p videos from YouTube is not supported.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>messageDialog</name>
    <message>
        <location filename="message_dialog.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="message_dialog.ui" line="48"/>
        <source>Close this message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="message_dialog.ui" line="71"/>
        <source>about:blank</source>
        <translation type="unfinished">about:blank</translation>
    </message>
</context>
<context>
    <name>video</name>
    <message>
        <location filename="video.cpp" line="261"/>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
